@@ -23,6 +23,15 @@ GtkActionGroup *launchpad_integration_get_action_group  (void);
 void            launchpad_integration_add_ui            (GtkUIManager *ui,
 							 const char *path);
 
+/* Same as the above function, but allows optional separators to be added
+ * before and after the UI nodes. This is useful when the launchpad-integration
+ * script cannot be found in the path, and having two manually added separators
+ * to the menu looks out of place. */
+void            launchpad_integration_add_ui_with_separators (GtkUIManager *ui,
+							      const char *path,
+							      gboolean separator_before,
+							      gboolean separator_after);
+
 /* Add launchpad integration menu items to the given menu at the given
  * position.  If the position is negative, then it is used as an index
  * from the end of the menu.
@@ -33,4 +42,6 @@ void            launchpad_integration_add_items (GtkWidget *helpmenu,
 						 gboolean separator_before,
 						 gboolean separator_after);
 
+/* Used, but not prototyped until now. */
+void		launchpad_integration_add_item_factory ();
 G_END_DECLS
